@@ -3,6 +3,7 @@ from typing import Any, Callable, Dict, List, Optional
 from grpc.aio import Channel
 
 from pyinjective.client.model.pagination import PaginationOption
+from pyinjective.core.network import CookieAssistant
 from pyinjective.proto.injective.exchange.v1beta1 import (
     query_pb2 as exchange_query_pb,
     query_pb2_grpc as exchange_query_grpc,
@@ -11,9 +12,9 @@ from pyinjective.utils.grpc_api_request_assistant import GrpcApiRequestAssistant
 
 
 class ChainGrpcExchangeApi:
-    def __init__(self, channel: Channel, metadata_provider: Callable):
+    def __init__(self, channel: Channel, cookie_assistant: CookieAssistant):
         self._stub = exchange_query_grpc.QueryStub(channel)
-        self._assistant = GrpcApiRequestAssistant(metadata_provider=metadata_provider)
+        self._assistant = GrpcApiRequestAssistant(cookie_assistant=cookie_assistant)
 
     async def fetch_exchange_params(self) -> Dict[str, Any]:
         request = exchange_query_pb.QueryExchangeParamsRequest()
@@ -574,5 +575,65 @@ class ChainGrpcExchangeApi:
 
         return response
 
+    async def fetch_l3_derivative_orderbook(self, market_id: str) -> Dict[str, Any]:
+        request = exchange_query_pb.QueryFullDerivativeOrderbookRequest(market_id=market_id)
+        response = await self._execute_call(call=self._stub.L3DerivativeOrderBook, request=request)
+
+        return response
+
+    async def fetch_l3_spot_orderbook(self, market_id: str) -> Dict[str, Any]:
+        request = exchange_query_pb.QueryFullSpotOrderbookRequest(market_id=market_id)
+        response = await self._execute_call(call=self._stub.L3SpotOrderBook, request=request)
+
+        return response
+
+    async def fetch_market_balance(self, market_id: str) -> Dict[str, Any]:
+        request = exchange_query_pb.QueryMarketBalanceRequest(market_id=market_id)
+        response = await self._execute_call(call=self._stub.MarketBalance, request=request)
+
+        return response
+
+    async def fetch_market_balances(self) -> Dict[str, Any]:
+        request = exchange_query_pb.QueryMarketBalancesRequest()
+        response = await self._execute_call(call=self._stub.MarketBalances, request=request)
+
+        return response
+
+    async def fetch_denom_min_notional(self, denom: str) -> Dict[str, Any]:
+        request = exchange_query_pb.QueryDenomMinNotionalRequest(denom=denom)
+        response = await self._execute_call(call=self._stub.DenomMinNotional, request=request)
+
+        return response
+
+    async def fetch_denom_min_notionals(self) -> Dict[str, Any]:
+        request = exchange_query_pb.QueryDenomMinNotionalsRequest()
+        response = await self._execute_call(call=self._stub.DenomMinNotionals, request=request)
+        return response
+
+    async def fetch_active_stake_grant(self, grantee: str) -> Dict[str, Any]:
+        request = exchange_query_pb.QueryActiveStakeGrantRequest(grantee=grantee)
+        response = await self._execute_call(call=self._stub.ActiveStakeGrant, request=request)
+
+        return response
+
+    async def fetch_grant_authorization(
+        self,
+        granter: str,
+        grantee: str,
+    ) -> Dict[str, Any]:
+        request = exchange_query_pb.QueryGrantAuthorizationRequest(
+            granter=granter,
+            grantee=grantee,
+        )
+        response = await self._execute_call(call=self._stub.GrantAuthorization, request=request)
+
+        return response
+
+    async def fetch_grant_authorizations(self, granter: str) -> Dict[str, Any]:
+        request = exchange_query_pb.QueryGrantAuthorizationsRequest(granter=granter)
+        response = await self._execute_call(call=self._stub.GrantAuthorizations, request=request)
+
+        return response
+
     async def _execute_call(self, call: Callable, request) -> Dict[str, Any]:
         return await self._assistant.execute_call(call=call, request=request)
