@@ -3,6 +3,7 @@ from typing import Any, Callable, Dict, List, Optional
 from grpc.aio import Channel
 
 from pyinjective.client.model.pagination import PaginationOption
+from pyinjective.core.network import CookieAssistant
 from pyinjective.proto.exchange import (
     injective_derivative_exchange_rpc_pb2 as exchange_derivative_pb,
     injective_derivative_exchange_rpc_pb2_grpc as exchange_derivative_grpc,
@@ -11,9 +12,9 @@ from pyinjective.utils.grpc_api_request_assistant import GrpcApiRequestAssistant
 
 
 class IndexerGrpcDerivativeApi:
-    def __init__(self, channel: Channel, metadata_provider: Callable):
+    def __init__(self, channel: Channel, cookie_assistant: CookieAssistant):
         self._stub = self._stub = exchange_derivative_grpc.InjectiveDerivativeExchangeRPCStub(channel)
-        self._assistant = GrpcApiRequestAssistant(metadata_provider=metadata_provider)
+        self._assistant = GrpcApiRequestAssistant(cookie_assistant=cookie_assistant)
 
     async def fetch_markets(
         self,
@@ -57,14 +58,14 @@ class IndexerGrpcDerivativeApi:
 
         return response
 
-    async def fetch_orderbook_v2(self, market_id: str) -> Dict[str, Any]:
-        request = exchange_derivative_pb.OrderbookV2Request(market_id=market_id)
+    async def fetch_orderbook_v2(self, market_id: str, depth: int) -> Dict[str, Any]:
+        request = exchange_derivative_pb.OrderbookV2Request(market_id=market_id, depth=depth)
         response = await self._execute_call(call=self._stub.OrderbookV2, request=request)
 
         return response
 
-    async def fetch_orderbooks_v2(self, market_ids: List[str]) -> Dict[str, Any]:
-        request = exchange_derivative_pb.OrderbooksV2Request(market_ids=market_ids)
+    async def fetch_orderbooks_v2(self, market_ids: List[str], depth: int) -> Dict[str, Any]:
+        request = exchange_derivative_pb.OrderbooksV2Request(market_ids=market_ids, depth=depth)
         response = await self._execute_call(call=self._stub.OrderbooksV2, request=request)
 
         return response
@@ -213,6 +214,7 @@ class IndexerGrpcDerivativeApi:
         trade_id: Optional[str] = None,
         account_address: Optional[str] = None,
         cid: Optional[str] = None,
+        fee_recipient: Optional[str] = None,
         pagination: Optional[PaginationOption] = None,
     ) -> Dict[str, Any]:
         pagination = pagination or PaginationOption()
@@ -229,6 +231,7 @@ class IndexerGrpcDerivativeApi:
             trade_id=trade_id,
             account_address=account_address,
             cid=cid,
+            fee_recipient=fee_recipient,
         )
 
         response = await self._execute_call(call=self._stub.Trades, request=request)
@@ -321,6 +324,7 @@ class IndexerGrpcDerivativeApi:
         trade_id: Optional[str] = None,
         account_address: Optional[str] = None,
         cid: Optional[str] = None,
+        fee_recipient: Optional[str] = None,
         pagination: Optional[PaginationOption] = None,
     ) -> Dict[str, Any]:
         pagination = pagination or PaginationOption()
@@ -337,11 +341,18 @@ class IndexerGrpcDerivativeApi:
             trade_id=trade_id,
             account_address=account_address,
             cid=cid,
+            fee_recipient=fee_recipient,
         )
 
         response = await self._execute_call(call=self._stub.TradesV2, request=request)
 
         return response
 
+    async def fetch_open_interest(self, market_ids: List[str]) -> Dict[str, Any]:
+        request = exchange_derivative_pb.OpenInterestRequest(market_i_ds=market_ids)
+        response = await self._execute_call(call=self._stub.OpenInterest, request=request)
+
+        return response
+
     async def _execute_call(self, call: Callable, request) -> Dict[str, Any]:
         return await self._assistant.execute_call(call=call, request=request)
