@@ -3,6 +3,7 @@ from typing import Any, Callable, Dict, List, Optional
 from grpc.aio import Channel
 
 from pyinjective.client.model.pagination import PaginationOption
+from pyinjective.core.network import CookieAssistant
 from pyinjective.proto.exchange import (
     injective_explorer_rpc_pb2 as exchange_explorer_pb,
     injective_explorer_rpc_pb2_grpc as exchange_explorer_grpc,
@@ -11,9 +12,9 @@ from pyinjective.utils.grpc_api_request_assistant import GrpcApiRequestAssistant
 
 
 class IndexerGrpcExplorerApi:
-    def __init__(self, channel: Channel, metadata_provider: Callable):
+    def __init__(self, channel: Channel, cookie_assistant: CookieAssistant):
         self._stub = self._stub = exchange_explorer_grpc.InjectiveExplorerRPCStub(channel)
-        self._assistant = GrpcApiRequestAssistant(metadata_provider=metadata_provider)
+        self._assistant = GrpcApiRequestAssistant(cookie_assistant=cookie_assistant)
 
     async def fetch_account_txs(
         self,
@@ -67,6 +68,32 @@ class IndexerGrpcExplorerApi:
 
         return response
 
+    async def fetch_contract_txs_v2(
+        self,
+        address: str,
+        height: Optional[int] = None,
+        token: Optional[str] = None,
+        status: Optional[str] = None,
+        pagination: Optional[PaginationOption] = None,
+    ) -> Dict[str, Any]:
+        pagination = pagination or PaginationOption()
+        request = exchange_explorer_pb.GetContractTxsV2Request(
+            address=address,
+            token=token,
+        )
+        if height is not None:
+            request.height = height
+        if pagination is not None:
+            setattr(request, "from", pagination.start_time)
+            request.to = pagination.end_time
+            request.per_page = pagination.limit
+        if status is not None:
+            request.status = status
+
+        response = await self._execute_call(call=self._stub.GetContractTxsV2, request=request)
+
+        return response
+
     async def fetch_blocks(
         self,
         before: Optional[int] = None,
@@ -213,15 +240,13 @@ class IndexerGrpcExplorerApi:
 
     async def fetch_wasm_codes(
         self,
-        from_number: Optional[int] = None,
-        to_number: Optional[int] = None,
         pagination: Optional[PaginationOption] = None,
     ) -> Dict[str, Any]:
         pagination = pagination or PaginationOption()
         request = exchange_explorer_pb.GetWasmCodesRequest(
             limit=pagination.limit,
-            from_number=from_number,
-            to_number=to_number,
+            from_number=pagination.from_number,
+            to_number=pagination.to_number,
         )
 
         response = await self._execute_call(call=self._stub.GetWasmCodes, request=request)
@@ -241,21 +266,23 @@ class IndexerGrpcExplorerApi:
     async def fetch_wasm_contracts(
         self,
         code_id: Optional[int] = None,
-        from_number: Optional[int] = None,
-        to_number: Optional[int] = None,
         assets_only: Optional[bool] = None,
         label: Optional[str] = None,
+        token: Optional[str] = None,
+        lookup: Optional[str] = None,
         pagination: Optional[PaginationOption] = None,
     ) -> Dict[str, Any]:
         pagination = pagination or PaginationOption()
         request = exchange_explorer_pb.GetWasmContractsRequest(
             limit=pagination.limit,
             code_id=code_id,
-            from_number=from_number,
-            to_number=to_number,
+            from_number=pagination.from_number,
+            to_number=pagination.to_number,
             assets_only=assets_only,
             skip=pagination.skip,
             label=label,
+            token=token,
+            lookup=lookup,
         )
 
         response = await self._execute_call(call=self._stub.GetWasmContracts, request=request)
