@@ -3,6 +3,7 @@ from typing import Any, Callable, Dict, List, Optional
 from grpc.aio import Channel
 
 from pyinjective.client.model.pagination import PaginationOption
+from pyinjective.core.network import CookieAssistant
 from pyinjective.proto.exchange import (
     injective_spot_exchange_rpc_pb2 as exchange_spot_pb,
     injective_spot_exchange_rpc_pb2_grpc as exchange_spot_grpc,
@@ -11,9 +12,9 @@ from pyinjective.utils.grpc_api_request_assistant import GrpcApiRequestAssistant
 
 
 class IndexerGrpcSpotApi:
-    def __init__(self, channel: Channel, metadata_provider: Callable):
+    def __init__(self, channel: Channel, cookie_assistant: CookieAssistant):
         self._stub = self._stub = exchange_spot_grpc.InjectiveSpotExchangeRPCStub(channel)
-        self._assistant = GrpcApiRequestAssistant(metadata_provider=metadata_provider)
+        self._assistant = GrpcApiRequestAssistant(cookie_assistant=cookie_assistant)
 
     async def fetch_markets(
         self,
@@ -36,14 +37,14 @@ class IndexerGrpcSpotApi:
 
         return response
 
-    async def fetch_orderbook_v2(self, market_id: str) -> Dict[str, Any]:
-        request = exchange_spot_pb.OrderbookV2Request(market_id=market_id)
+    async def fetch_orderbook_v2(self, market_id: str, depth: int) -> Dict[str, Any]:
+        request = exchange_spot_pb.OrderbookV2Request(market_id=market_id, depth=depth)
         response = await self._execute_call(call=self._stub.OrderbookV2, request=request)
 
         return response
 
-    async def fetch_orderbooks_v2(self, market_ids: List[str]) -> Dict[str, Any]:
-        request = exchange_spot_pb.OrderbooksV2Request(market_ids=market_ids)
+    async def fetch_orderbooks_v2(self, market_ids: List[str], depth: int) -> Dict[str, Any]:
+        request = exchange_spot_pb.OrderbooksV2Request(market_ids=market_ids, depth=depth)
         response = await self._execute_call(call=self._stub.OrderbooksV2, request=request)
 
         return response
@@ -88,6 +89,7 @@ class IndexerGrpcSpotApi:
         trade_id: Optional[str] = None,
         account_address: Optional[str] = None,
         cid: Optional[str] = None,
+        fee_recipient: Optional[str] = None,
         pagination: Optional[PaginationOption] = None,
     ) -> Dict[str, Any]:
         pagination = pagination or PaginationOption()
@@ -104,6 +106,7 @@ class IndexerGrpcSpotApi:
             trade_id=trade_id,
             account_address=account_address,
             cid=cid,
+            fee_recipient=fee_recipient,
         )
 
         response = await self._execute_call(call=self._stub.Trades, request=request)
@@ -214,6 +217,7 @@ class IndexerGrpcSpotApi:
         trade_id: Optional[str] = None,
         account_address: Optional[str] = None,
         cid: Optional[str] = None,
+        fee_recipient: Optional[str] = None,
         pagination: Optional[PaginationOption] = None,
     ) -> Dict[str, Any]:
         pagination = pagination or PaginationOption()
@@ -230,6 +234,7 @@ class IndexerGrpcSpotApi:
             trade_id=trade_id,
             account_address=account_address,
             cid=cid,
+            fee_recipient=fee_recipient,
         )
 
         response = await self._execute_call(call=self._stub.TradesV2, request=request)
