@@ -3,6 +3,7 @@ from typing import Callable, List, Optional
 from grpc.aio import Channel
 
 from pyinjective.client.model.pagination import PaginationOption
+from pyinjective.core.network import CookieAssistant
 from pyinjective.proto.exchange import (
     injective_derivative_exchange_rpc_pb2 as exchange_derivative_pb,
     injective_derivative_exchange_rpc_pb2_grpc as exchange_derivative_grpc,
@@ -11,9 +12,9 @@ from pyinjective.utils.grpc_api_stream_assistant import GrpcApiStreamAssistant
 
 
 class IndexerGrpcDerivativeStream:
-    def __init__(self, channel: Channel, metadata_provider: Callable):
+    def __init__(self, channel: Channel, cookie_assistant: CookieAssistant):
         self._stub = self._stub = exchange_derivative_grpc.InjectiveDerivativeExchangeRPCStub(channel)
-        self._assistant = GrpcApiStreamAssistant(metadata_provider=metadata_provider)
+        self._assistant = GrpcApiStreamAssistant(cookie_assistant=cookie_assistant)
 
     async def stream_market(
         self,
@@ -140,6 +141,7 @@ class IndexerGrpcDerivativeStream:
         trade_id: Optional[str] = None,
         account_address: Optional[str] = None,
         cid: Optional[str] = None,
+        fee_recipient: Optional[str] = None,
         pagination: Optional[PaginationOption] = None,
     ):
         pagination = pagination or PaginationOption()
@@ -155,6 +157,7 @@ class IndexerGrpcDerivativeStream:
             execution_types=execution_types,
             trade_id=trade_id,
             account_address=account_address,
+            fee_recipient=fee_recipient,
             cid=cid,
         )
 
@@ -208,6 +211,7 @@ class IndexerGrpcDerivativeStream:
         trade_id: Optional[str] = None,
         account_address: Optional[str] = None,
         cid: Optional[str] = None,
+        fee_recipient: Optional[str] = None,
         pagination: Optional[PaginationOption] = None,
     ):
         pagination = pagination or PaginationOption()
@@ -224,6 +228,7 @@ class IndexerGrpcDerivativeStream:
             trade_id=trade_id,
             account_address=account_address,
             cid=cid,
+            fee_recipient=fee_recipient,
         )
 
         await self._assistant.listen_stream(
@@ -233,3 +238,30 @@ class IndexerGrpcDerivativeStream:
             on_end_callback=on_end_callback,
             on_status_callback=on_status_callback,
         )
+
+    async def stream_positions_v2(
+        self,
+        callback: Callable,
+        on_end_callback: Optional[Callable] = None,
+        on_status_callback: Optional[Callable] = None,
+        subaccount_id: Optional[str] = None,
+        market_id: Optional[str] = None,
+        market_ids: Optional[List[str]] = None,
+        subaccount_ids: Optional[List[str]] = None,
+        account_address: Optional[str] = None,
+    ):
+        request = exchange_derivative_pb.StreamPositionsV2Request(
+            subaccount_id=subaccount_id,
+            market_id=market_id,
+            market_ids=market_ids,
+            subaccount_ids=subaccount_ids,
+            account_address=account_address,
+        )
+
+        await self._assistant.listen_stream(
+            call=self._stub.StreamPositionsV2,
+            request=request,
+            callback=callback,
+            on_end_callback=on_end_callback,
+            on_status_callback=on_status_callback,
+        )
