@@ -3,6 +3,7 @@ from typing import Callable, List, Optional
 from grpc.aio import Channel
 
 from pyinjective.client.model.pagination import PaginationOption
+from pyinjective.core.network import CookieAssistant
 from pyinjective.proto.exchange import (
     injective_spot_exchange_rpc_pb2 as exchange_spot_pb,
     injective_spot_exchange_rpc_pb2_grpc as exchange_spot_grpc,
@@ -11,9 +12,9 @@ from pyinjective.utils.grpc_api_stream_assistant import GrpcApiStreamAssistant
 
 
 class IndexerGrpcSpotStream:
-    def __init__(self, channel: Channel, metadata_provider: Callable):
+    def __init__(self, channel: Channel, cookie_assistant: CookieAssistant):
         self._stub = self._stub = exchange_spot_grpc.InjectiveSpotExchangeRPCStub(channel)
-        self._assistant = GrpcApiStreamAssistant(metadata_provider=metadata_provider)
+        self._assistant = GrpcApiStreamAssistant(cookie_assistant=cookie_assistant)
 
     async def stream_markets(
         self,
@@ -118,6 +119,7 @@ class IndexerGrpcSpotStream:
         trade_id: Optional[str] = None,
         account_address: Optional[str] = None,
         cid: Optional[str] = None,
+        fee_recipient: Optional[str] = None,
         pagination: Optional[PaginationOption] = None,
     ):
         pagination = pagination or PaginationOption()
@@ -134,6 +136,7 @@ class IndexerGrpcSpotStream:
             trade_id=trade_id,
             account_address=account_address,
             cid=cid,
+            fee_recipient=fee_recipient,
         )
 
         await self._assistant.listen_stream(
@@ -186,6 +189,7 @@ class IndexerGrpcSpotStream:
         trade_id: Optional[str] = None,
         account_address: Optional[str] = None,
         cid: Optional[str] = None,
+        fee_recipient: Optional[str] = None,
         pagination: Optional[PaginationOption] = None,
     ):
         pagination = pagination or PaginationOption()
@@ -202,6 +206,7 @@ class IndexerGrpcSpotStream:
             trade_id=trade_id,
             account_address=account_address,
             cid=cid,
+            fee_recipient=fee_recipient,
         )
 
         await self._assistant.listen_stream(
