@@ -1,5 +1,5 @@
 from dataclasses import dataclass
-from decimal import Decimal
+from decimal import ROUND_UP, Decimal
 from typing import Optional
 
 from pyinjective.constant import ADDITIONAL_CHAIN_FORMAT_DECIMALS
@@ -19,6 +19,7 @@ class SpotMarket:
     service_provider_fee: Decimal
     min_price_tick_size: Decimal
     min_quantity_tick_size: Decimal
+    min_notional: Decimal
 
     def quantity_to_chain_format(self, human_readable_value: Decimal) -> Decimal:
         chain_formatted_value = human_readable_value * Decimal(f"1e{self.base_token.decimals}")
@@ -35,6 +36,14 @@ class SpotMarket:
 
         return extended_chain_formatted_value
 
+    def notional_to_chain_format(self, human_readable_value: Decimal) -> Decimal:
+        decimals = self.quote_token.decimals
+        chain_formatted_value = human_readable_value * Decimal(f"1e{decimals}")
+        quantized_balue = chain_formatted_value.quantize(Decimal("1"), rounding=ROUND_UP)
+        extended_chain_formatted_value = quantized_balue * Decimal(f"1e{ADDITIONAL_CHAIN_FORMAT_DECIMALS}")
+
+        return extended_chain_formatted_value
+
     def quantity_from_chain_format(self, chain_value: Decimal) -> Decimal:
         return chain_value / Decimal(f"1e{self.base_token.decimals}")
 
@@ -42,12 +51,18 @@ class SpotMarket:
         decimals = self.base_token.decimals - self.quote_token.decimals
         return chain_value * Decimal(f"1e{decimals}")
 
+    def notional_from_chain_format(self, chain_value: Decimal) -> Decimal:
+        return chain_value / Decimal(f"1e{self.quote_token.decimals}")
+
     def quantity_from_extended_chain_format(self, chain_value: Decimal) -> Decimal:
         return self._from_extended_chain_format(chain_value=self.quantity_from_chain_format(chain_value=chain_value))
 
     def price_from_extended_chain_format(self, chain_value: Decimal) -> Decimal:
         return self._from_extended_chain_format(chain_value=self.price_from_chain_format(chain_value=chain_value))
 
+    def notional_from_extended_chain_format(self, chain_value: Decimal) -> Decimal:
+        return self._from_extended_chain_format(chain_value=self.notional_from_chain_format(chain_value=chain_value))
+
     def _from_extended_chain_format(self, chain_value: Decimal) -> Decimal:
         return chain_value / Decimal(f"1e{ADDITIONAL_CHAIN_FORMAT_DECIMALS}")
 
@@ -69,6 +84,7 @@ class DerivativeMarket:
     service_provider_fee: Decimal
     min_price_tick_size: Decimal
     min_quantity_tick_size: Decimal
+    min_notional: Decimal
 
     def quantity_to_chain_format(self, human_readable_value: Decimal) -> Decimal:
         # Derivative markets do not have a base market to provide the number of decimals
@@ -87,12 +103,7 @@ class DerivativeMarket:
         return extended_chain_formatted_value
 
     def margin_to_chain_format(self, human_readable_value: Decimal) -> Decimal:
-        decimals = self.quote_token.decimals
-        chain_formatted_value = human_readable_value * Decimal(f"1e{decimals}")
-        quantized_value = (chain_formatted_value // self.min_quantity_tick_size) * self.min_quantity_tick_size
-        extended_chain_formatted_value = quantized_value * Decimal(f"1e{ADDITIONAL_CHAIN_FORMAT_DECIMALS}")
-
-        return extended_chain_formatted_value
+        return self.notional_to_chain_format(human_readable_value=human_readable_value)
 
     def calculate_margin_in_chain_format(
         self, human_readable_quantity: Decimal, human_readable_price: Decimal, leverage: Decimal
@@ -107,6 +118,14 @@ class DerivativeMarket:
 
         return extended_chain_formatted_margin
 
+    def notional_to_chain_format(self, human_readable_value: Decimal) -> Decimal:
+        decimals = self.quote_token.decimals
+        chain_formatted_value = human_readable_value * Decimal(f"1e{decimals}")
+        quantized_notional = chain_formatted_value.quantize(Decimal("1"), rounding=ROUND_UP)
+        extended_chain_formatted_value = quantized_notional * Decimal(f"1e{ADDITIONAL_CHAIN_FORMAT_DECIMALS}")
+
+        return extended_chain_formatted_value
+
     def quantity_from_chain_format(self, chain_value: Decimal) -> Decimal:
         return chain_value
 
@@ -114,7 +133,10 @@ class DerivativeMarket:
         return chain_value * Decimal(f"1e-{self.quote_token.decimals}")
 
     def margin_from_chain_format(self, chain_value: Decimal) -> Decimal:
-        return chain_value * Decimal(f"1e-{self.quote_token.decimals}")
+        return self.notional_from_chain_format(chain_value=chain_value)
+
+    def notional_from_chain_format(self, chain_value: Decimal) -> Decimal:
+        return chain_value / Decimal(f"1e{self.quote_token.decimals}")
 
     def quantity_from_extended_chain_format(self, chain_value: Decimal) -> Decimal:
         return self._from_extended_chain_format(chain_value=self.quantity_from_chain_format(chain_value=chain_value))
@@ -123,7 +145,10 @@ class DerivativeMarket:
         return self._from_extended_chain_format(chain_value=self.price_from_chain_format(chain_value=chain_value))
 
     def margin_from_extended_chain_format(self, chain_value: Decimal) -> Decimal:
-        return self._from_extended_chain_format(chain_value=self.margin_from_chain_format(chain_value=chain_value))
+        return self.notional_from_extended_chain_format(chain_value=chain_value)
+
+    def notional_from_extended_chain_format(self, chain_value: Decimal) -> Decimal:
+        return self._from_extended_chain_format(chain_value=self.notional_from_chain_format(chain_value=chain_value))
 
     def _from_extended_chain_format(self, chain_value: Decimal) -> Decimal:
         return chain_value / Decimal(f"1e{ADDITIONAL_CHAIN_FORMAT_DECIMALS}")
@@ -146,6 +171,7 @@ class BinaryOptionMarket:
     service_provider_fee: Decimal
     min_price_tick_size: Decimal
     min_quantity_tick_size: Decimal
+    min_notional: Decimal
     settlement_price: Optional[Decimal] = None
 
     def quantity_to_chain_format(self, human_readable_value: Decimal, special_denom: Optional[Denom] = None) -> Decimal:
@@ -203,6 +229,14 @@ class BinaryOptionMarket:
 
         return extended_chain_formatted_margin
 
+    def notional_to_chain_format(self, human_readable_value: Decimal) -> Decimal:
+        decimals = self.quote_token.decimals
+        chain_formatted_value = human_readable_value * Decimal(f"1e{decimals}")
+        quantized_value = chain_formatted_value.quantize(Decimal("1"), rounding=ROUND_UP)
+        extended_chain_formatted_value = quantized_value * Decimal(f"1e{ADDITIONAL_CHAIN_FORMAT_DECIMALS}")
+
+        return extended_chain_formatted_value
+
     def quantity_from_chain_format(self, chain_value: Decimal, special_denom: Optional[Denom] = None) -> Decimal:
         # Binary option markets do not have a base market to provide the number of decimals
         decimals = 0 if special_denom is None else special_denom.base
@@ -212,6 +246,12 @@ class BinaryOptionMarket:
         decimals = self.quote_token.decimals if special_denom is None else special_denom.quote
         return chain_value * Decimal(f"1e-{decimals}")
 
+    def margin_from_chain_format(self, chain_value: Decimal) -> Decimal:
+        return self.notional_from_chain_format(chain_value=chain_value)
+
+    def notional_from_chain_format(self, chain_value: Decimal) -> Decimal:
+        return chain_value / Decimal(f"1e{self.quote_token.decimals}")
+
     def quantity_from_extended_chain_format(
         self, chain_value: Decimal, special_denom: Optional[Denom] = None
     ) -> Decimal:
@@ -224,5 +264,11 @@ class BinaryOptionMarket:
             chain_value=self.price_from_chain_format(chain_value=chain_value, special_denom=special_denom)
         )
 
+    def margin_from_extended_chain_format(self, chain_value: Decimal) -> Decimal:
+        return self.notional_from_extended_chain_format(chain_value=chain_value)
+
+    def notional_from_extended_chain_format(self, chain_value: Decimal) -> Decimal:
+        return self._from_extended_chain_format(chain_value=self.notional_from_chain_format(chain_value=chain_value))
+
     def _from_extended_chain_format(self, chain_value: Decimal) -> Decimal:
         return chain_value / Decimal(f"1e{ADDITIONAL_CHAIN_FORMAT_DECIMALS}")
