@@ -4,11 +4,13 @@ from typing import Callable, Optional
 from google.protobuf import json_format
 from grpc import RpcError
 
+from pyinjective.core.network import CookieAssistant
+
 
 class GrpcApiStreamAssistant:
-    def __init__(self, metadata_provider: Callable):
+    def __init__(self, cookie_assistant: CookieAssistant):
         super().__init__()
-        self._metadata_provider = metadata_provider
+        self._cookie_assistant = cookie_assistant
 
     async def listen_stream(
         self,
@@ -18,14 +20,14 @@ class GrpcApiStreamAssistant:
         on_end_callback: Optional[Callable] = None,
         on_status_callback: Optional[Callable] = None,
     ):
-        metadata = await self._metadata_provider()
+        metadata = self._cookie_assistant.metadata()
         stream = call(request, metadata=metadata)
 
         try:
             async for event in stream:
                 parsed_event = json_format.MessageToDict(
                     message=event,
-                    including_default_value_fields=True,
+                    always_print_fields_with_no_presence=True,
                 )
                 if asyncio.iscoroutinefunction(callback):
                     await callback(parsed_event)
