@@ -11,8 +11,8 @@ from ecdsa import BadSignatureError, SECP256k1, SigningKey, VerifyingKey
 from ecdsa.util import sigencode_string_canonize
 from mnemonic import Mnemonic
 
-from .exceptions import ConvertError, DecodeError
-from .proto.injective.crypto.v1beta1.ethsecp256k1.keys_pb2 import PubKey as PubKeyProto
+from pyinjective.exceptions import ConvertError, DecodeError
+from pyinjective.proto.injective.crypto.v1beta1.ethsecp256k1.keys_pb2 import PubKey as PubKeyProto
 
 BECH32_PUBKEY_ACC_PREFIX = "injpub"
 BECH32_PUBKEY_VAL_PREFIX = "injvaloperpub"
@@ -232,6 +232,13 @@ class Address:
         """Create an address instance from a bech32-encoded consensus address"""
         return cls._from_bech32(bech, BECH32_ADDR_CONS_PREFIX)
 
+    @classmethod
+    def from_eth_address(cls, eth_address: str) -> "Address":
+        """Create an address instance from a hex-encoded Ethereum address"""
+        eth_address_without_prefix = eth_address[2:] if eth_address.startswith("0x") else eth_address
+        bytes_representation = bytes.fromhex(eth_address_without_prefix)
+        return cls(bytes_representation)
+
     def _to_bech32(self, prefix: str) -> str:
         five_bit_r = convertbits(self.addr, 8, 5)
         assert five_bit_r is not None, "Unsuccessful bech32.convertbits call"
